<?php
namespace Aws\CodeConnections\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS CodeConnections** service.
 */
class CodeConnectionsException extends AwsException {}
